######
pynsot
######

.. image:: https://travis-ci.org/dropbox/pynsot.svg
    :target: https://travis-ci.org/dropbox/pynsot

Python client library and command-line utility for the `Network Source of
Truth <https://github.com/dropbox/nsot>`_ (NSoT) REST API.

Read the docs at http://pynsot.rtfd.org
